==> google-cloud-recommender-2.13.0rc0.tar.gz: google-cloud-recommender-2.13.0rc0/google/cloud/recommender_v1beta1/services/recommender/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.recommender_v1beta1 import gapic_version as package_version
from google.cloud.recommender_v1beta1.types import (
    insight_type_config as gcr_insight_type_config,
)
from google.cloud.recommender_v1beta1.types import (
    recommender_config as gcr_recommender_config,
)
from google.cloud.recommender_v1beta1.types import insight
from google.cloud.recommender_v1beta1.types import insight_type_config
from google.cloud.recommender_v1beta1.types import recommendation
from google.cloud.recommender_v1beta1.types import recommender_config
from google.cloud.recommender_v1beta1.types import recommender_service

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class RecommenderTransport(abc.ABC):
    """Abstract transport class for Recommender."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "recommender.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_insights: gapic_v1.method.wrap_method(
                self.list_insights,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_insight: gapic_v1.method.wrap_method(
                self.get_insight,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mark_insight_accepted: gapic_v1.method.wrap_method(
                self.mark_insight_accepted,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_recommendations: gapic_v1.method.wrap_method(
                self.list_recommendations,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_recommendation: gapic_v1.method.wrap_method(
                self.get_recommendation,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mark_recommendation_claimed: gapic_v1.method.wrap_method(
                self.mark_recommendation_claimed,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mark_recommendation_succeeded: gapic_v1.method.wrap_method(
                self.mark_recommendation_succeeded,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mark_recommendation_failed: gapic_v1.method.wrap_method(
                self.mark_recommendation_failed,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_recommender_config: gapic_v1.method.wrap_method(
                self.get_recommender_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_recommender_config: gapic_v1.method.wrap_method(
                self.update_recommender_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_insight_type_config: gapic_v1.method.wrap_method(
                self.get_insight_type_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_insight_type_config: gapic_v1.method.wrap_method(
                self.update_insight_type_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_recommenders: gapic_v1.method.wrap_method(
                self.list_recommenders,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_insight_types: gapic_v1.method.wrap_method(
                self.list_insight_types,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def list_insights(
        self,
    ) -> Callable[
        [recommender_service.ListInsightsRequest],
        Union[
            recommender_service.ListInsightsResponse,
            Awaitable[recommender_service.ListInsightsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_insight(
        self,
    ) -> Callable[
        [recommender_service.GetInsightRequest],
        Union[insight.Insight, Awaitable[insight.Insight]],
    ]:
        raise NotImplementedError()

    @property
    def mark_insight_accepted(
        self,
    ) -> Callable[
        [recommender_service.MarkInsightAcceptedRequest],
        Union[insight.Insight, Awaitable[insight.Insight]],
    ]:
        raise NotImplementedError()

    @property
    def list_recommendations(
        self,
    ) -> Callable[
        [recommender_service.ListRecommendationsRequest],
        Union[
            recommender_service.ListRecommendationsResponse,
            Awaitable[recommender_service.ListRecommendationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_recommendation(
        self,
    ) -> Callable[
        [recommender_service.GetRecommendationRequest],
        Union[recommendation.Recommendation, Awaitable[recommendation.Recommendation]],
    ]:
        raise NotImplementedError()

    @property
    def mark_recommendation_claimed(
        self,
    ) -> Callable[
        [recommender_service.MarkRecommendationClaimedRequest],
        Union[recommendation.Recommendation, Awaitable[recommendation.Recommendation]],
    ]:
        raise NotImplementedError()

    @property
    def mark_recommendation_succeeded(
        self,
    ) -> Callable[
        [recommender_service.MarkRecommendationSucceededRequest],
        Union[recommendation.Recommendation, Awaitable[recommendation.Recommendation]],
    ]:
        raise NotImplementedError()

    @property
    def mark_recommendation_failed(
        self,
    ) -> Callable[
        [recommender_service.MarkRecommendationFailedRequest],
        Union[recommendation.Recommendation, Awaitable[recommendation.Recommendation]],
    ]:
        raise NotImplementedError()

    @property
    def get_recommender_config(
        self,
    ) -> Callable[
        [recommender_service.GetRecommenderConfigRequest],
        Union[
            recommender_config.RecommenderConfig,
            Awaitable[recommender_config.RecommenderConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_recommender_config(
        self,
    ) -> Callable[
        [recommender_service.UpdateRecommenderConfigRequest],
        Union[
            gcr_recommender_config.RecommenderConfig,
            Awaitable[gcr_recommender_config.RecommenderConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_insight_type_config(
        self,
    ) -> Callable[
        [recommender_service.GetInsightTypeConfigRequest],
        Union[
            insight_type_config.InsightTypeConfig,
            Awaitable[insight_type_config.InsightTypeConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_insight_type_config(
        self,
    ) -> Callable[
        [recommender_service.UpdateInsightTypeConfigRequest],
        Union[
            gcr_insight_type_config.InsightTypeConfig,
            Awaitable[gcr_insight_type_config.InsightTypeConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_recommenders(
        self,
    ) -> Callable[
        [recommender_service.ListRecommendersRequest],
        Union[
            recommender_service.ListRecommendersResponse,
            Awaitable[recommender_service.ListRecommendersResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_insight_types(
        self,
    ) -> Callable[
        [recommender_service.ListInsightTypesRequest],
        Union[
            recommender_service.ListInsightTypesResponse,
            Awaitable[recommender_service.ListInsightTypesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("RecommenderTransport",)

==> google-cloud-recommender-2.15.3.tar.gz: google-cloud-recommender-2.15.3/google/cloud/recommender_v1beta1/services/recommender/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.recommender_v1beta1 import gapic_version as package_version
from google.cloud.recommender_v1beta1.types import (
    insight_type_config as gcr_insight_type_config,
)
from google.cloud.recommender_v1beta1.types import (
    recommender_config as gcr_recommender_config,
)
from google.cloud.recommender_v1beta1.types import insight
from google.cloud.recommender_v1beta1.types import insight_type_config
from google.cloud.recommender_v1beta1.types import recommendation
from google.cloud.recommender_v1beta1.types import recommender_config
from google.cloud.recommender_v1beta1.types import recommender_service

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class RecommenderTransport(abc.ABC):
    """Abstract transport class for Recommender."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "recommender.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'recommender.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    @property
    def host(self):
        return self._host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_insights: gapic_v1.method.wrap_method(
                self.list_insights,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_insight: gapic_v1.method.wrap_method(
                self.get_insight,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mark_insight_accepted: gapic_v1.method.wrap_method(
                self.mark_insight_accepted,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_recommendations: gapic_v1.method.wrap_method(
                self.list_recommendations,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_recommendation: gapic_v1.method.wrap_method(
                self.get_recommendation,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mark_recommendation_claimed: gapic_v1.method.wrap_method(
                self.mark_recommendation_claimed,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mark_recommendation_succeeded: gapic_v1.method.wrap_method(
                self.mark_recommendation_succeeded,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mark_recommendation_failed: gapic_v1.method.wrap_method(
                self.mark_recommendation_failed,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_recommender_config: gapic_v1.method.wrap_method(
                self.get_recommender_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_recommender_config: gapic_v1.method.wrap_method(
                self.update_recommender_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_insight_type_config: gapic_v1.method.wrap_method(
                self.get_insight_type_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_insight_type_config: gapic_v1.method.wrap_method(
                self.update_insight_type_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_recommenders: gapic_v1.method.wrap_method(
                self.list_recommenders,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_insight_types: gapic_v1.method.wrap_method(
                self.list_insight_types,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def list_insights(
        self,
    ) -> Callable[
        [recommender_service.ListInsightsRequest],
        Union[
            recommender_service.ListInsightsResponse,
            Awaitable[recommender_service.ListInsightsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_insight(
        self,
    ) -> Callable[
        [recommender_service.GetInsightRequest],
        Union[insight.Insight, Awaitable[insight.Insight]],
    ]:
        raise NotImplementedError()

    @property
    def mark_insight_accepted(
        self,
    ) -> Callable[
        [recommender_service.MarkInsightAcceptedRequest],
        Union[insight.Insight, Awaitable[insight.Insight]],
    ]:
        raise NotImplementedError()

    @property
    def list_recommendations(
        self,
    ) -> Callable[
        [recommender_service.ListRecommendationsRequest],
        Union[
            recommender_service.ListRecommendationsResponse,
            Awaitable[recommender_service.ListRecommendationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_recommendation(
        self,
    ) -> Callable[
        [recommender_service.GetRecommendationRequest],
        Union[recommendation.Recommendation, Awaitable[recommendation.Recommendation]],
    ]:
        raise NotImplementedError()

    @property
    def mark_recommendation_claimed(
        self,
    ) -> Callable[
        [recommender_service.MarkRecommendationClaimedRequest],
        Union[recommendation.Recommendation, Awaitable[recommendation.Recommendation]],
    ]:
        raise NotImplementedError()

    @property
    def mark_recommendation_succeeded(
        self,
    ) -> Callable[
        [recommender_service.MarkRecommendationSucceededRequest],
        Union[recommendation.Recommendation, Awaitable[recommendation.Recommendation]],
    ]:
        raise NotImplementedError()

    @property
    def mark_recommendation_failed(
        self,
    ) -> Callable[
        [recommender_service.MarkRecommendationFailedRequest],
        Union[recommendation.Recommendation, Awaitable[recommendation.Recommendation]],
    ]:
        raise NotImplementedError()

    @property
    def get_recommender_config(
        self,
    ) -> Callable[
        [recommender_service.GetRecommenderConfigRequest],
        Union[
            recommender_config.RecommenderConfig,
            Awaitable[recommender_config.RecommenderConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_recommender_config(
        self,
    ) -> Callable[
        [recommender_service.UpdateRecommenderConfigRequest],
        Union[
            gcr_recommender_config.RecommenderConfig,
            Awaitable[gcr_recommender_config.RecommenderConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_insight_type_config(
        self,
    ) -> Callable[
        [recommender_service.GetInsightTypeConfigRequest],
        Union[
            insight_type_config.InsightTypeConfig,
            Awaitable[insight_type_config.InsightTypeConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_insight_type_config(
        self,
    ) -> Callable[
        [recommender_service.UpdateInsightTypeConfigRequest],
        Union[
            gcr_insight_type_config.InsightTypeConfig,
            Awaitable[gcr_insight_type_config.InsightTypeConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_recommenders(
        self,
    ) -> Callable[
        [recommender_service.ListRecommendersRequest],
        Union[
            recommender_service.ListRecommendersResponse,
            Awaitable[recommender_service.ListRecommendersResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_insight_types(
        self,
    ) -> Callable[
        [recommender_service.ListInsightTypesRequest],
        Union[
            recommender_service.ListInsightTypesResponse,
            Awaitable[recommender_service.ListInsightTypesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("RecommenderTransport",)
